Empty example PYPI package by The1bit
--------------------------------------

Change log 
----------

* version 0.0.0.3
    * Test Azure DevOps pipeline
* version 0.0.0.1
    * Init files and directory structure



Requirements
------------

* Linux OS or Windows OS
* Python (2.7)


Basic install
-------------

pip install [package name] --upgrade

(install without cache: pip install [package name] --no-cache-dir  )



You can find the detailed documentation in https://github.com/the1bit/pypi-project.


Please read the license related information.

